@@ -147,21 +147,31 @@ class Batch:
         combo()
 
     def help(self):
-        _self_ = '\n\t'.join(['%s=%s'% (k, vars(self)[k]) for k in vars(self)])
-        print(f"""
-data: enumerate,
-rate: int = __cpu__(),
-scale: int = 0,
-interval: float = 1,
-output: str = '_output.txt',
-write: callable = __write__,
-progress: str = '_progress.txt',
-checkpoint: callable = __checkpoint__,
-visual: callable = __visual__
+        print(f'''
+data: enumerate
+    enumerable object to run through
+rate: int (batchelor.__cpu__())
+    how many workers to keep alive at once
+scale: int (0)
+    queue scale (0 == rate*rate)
+interval: int (1)
+    how fast to spawn new workers
+output: str ('_output.txt')
+    filename to save to
+write: function (batchelor.__write__)
+    save(output)
+progress: str ('_progress.txt')
+    progress file
+checkpoint: function (batchelor.__checkpoint__)
+    save/restore(save=True/False)
+visual: function (batchelor.__visual__)  # x ~y +z -a
+    visual status updates
+
+NOTE: every function was made to be easily monkeypatched, so use it if you want.
+
 If you need more help, then look at the source code here: https://github.com/ritzKraka/python-batchelor
-self:
-    {_self_}
-        """)
+
+{vars(self)}''')
 
 
 def prompt(save, preset=False):
@@ -183,5 +193,5 @@ def launch(fn: callable, save=__save_name__, data=False, preset=False):
     if data:
         Batch(data, *prompt(save, preset=preset)).start(fn)
     else:
-        with open(input(f'data file (?/d_{save__}.txt) ') or f'd_{save}.txt', 'r') as f:
+        with open(input(f'data file (?/d_{save}.txt) ') or f'd_{save}.txt', 'r') as f:
             Batch(enumerate(data), *prompt(save, preset=preset)).start(fn)
